@@ -1,7 +1,14 @@
 from .plotpretty import *
+import os
 
 def joke(): return 'nah'
 
+def exporthtml():
+	os.system('jupyter nbconvert --to=html ' +  os.path.abspath(__file__))
+
+def exportpdf():
+	os.system('jupyter nbconvert --to=pdf --template=jb4jupyter ' + os.path.abspath(__file__))
+
 def configlatexprint():
 	lines = [
 		'((* extends \'article.tplx\' *)) \n',
